Module layer

Module layer 

NetworkLayer for local BACnet packet assembly and dispatch.

The network layer wraps a transport and provides APDU-level send/receive by handling NPDU encoding/decoding. This is a non-router implementation: it does not forward messages between networks, but it can address remote devices through local routers via NPDU destination fields (DNET/DADR).

Structs

NetworkLayer
Non-router BACnet network layer.
ReceivedApdu
A received APDU with source addressing information.