NetworkLayer for local BACnet packet assembly and dispatch.
The network layer wraps a transport and provides APDU-level send/receive by handling NPDU encoding/decoding. This is a non-router implementation: it does not forward messages between networks, but it can address remote devices through local routers via NPDU destination fields (DNET/DADR).
Structs
- Network
Layer - Non-router BACnet network layer.
- Received
Apdu - A received APDU with source addressing information.